gc3libs.application.demo — gc3pie development (SVN $Revision$) documentation

### Navigation

- index
- modules |
- next |
- previous |
- gc3pie development (SVN $Revision$) documentation »
- Programmer Documentation »
- GC3Libs programming API »

# gc3libs.application.demo

Specialized support for computational jobs running simple demo.

class `gc3libs.application.demo.` `Square`(x)

  Square class, takes a filename containing a list of integer to be squared. writes an output containing the square of each of them

### Navigation

- index
- modules |
- next |
- previous |
- gc3pie development (SVN $Revision$) documentation »
- Programmer Documentation »
- GC3Libs programming API »